/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.layout.page.template.admin.web.internal.exporter;

import com.liferay.layout.page.template.exporter.PortletConfigurationExporter;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferenceCardinality;
import org.osgi.service.component.annotations.ReferencePolicy;

/**
 * @author Jürgen Kappler
 */
@Component(service = PortletConfigurationExporterTracker.class)
public class PortletConfigurationExporterTracker {

	public PortletConfigurationExporter getPortletConfigurationExporter(
		String portletName) {

		return _portletConfigurationExporters.get(portletName);
	}

	@Reference(
		cardinality = ReferenceCardinality.MULTIPLE,
		policy = ReferencePolicy.DYNAMIC
	)
	protected void setPortletConfigurationExporter(
		PortletConfigurationExporter portletConfigurationExporter) {

		_portletConfigurationExporters.put(
			portletConfigurationExporter.getPortletName(),
			portletConfigurationExporter);
	}

	protected void unsetPortletConfigurationExporter(
		PortletConfigurationExporter portletConfigurationExporter) {

		_portletConfigurationExporters.remove(portletConfigurationExporter);
	}

	private final Map<String, PortletConfigurationExporter>
		_portletConfigurationExporters = new ConcurrentHashMap<>();

}