/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.layout.page.template.admin.web.internal.headless.delivery.dto.v1_0.structure.exporter;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;
import org.osgi.service.component.annotations.ReferenceCardinality;
import org.osgi.service.component.annotations.ReferencePolicy;

/**
 * @author Jürgen Kappler
 */
@Component(service = LayoutStructureItemExporterTracker.class)
public class LayoutStructureItemExporterTracker {

	public LayoutStructureItemExporter getLayoutStructureItemExporter(
		String className) {

		return _layoutStructureItemExporters.get(className);
	}

	@Reference(
		cardinality = ReferenceCardinality.MULTIPLE,
		policy = ReferencePolicy.DYNAMIC
	)
	protected void setLayoutStructureItemExporter(
		LayoutStructureItemExporter layoutStructureItemExporter) {

		_layoutStructureItemExporters.put(
			layoutStructureItemExporter.getClassName(),
			layoutStructureItemExporter);
	}

	protected void unsetLayoutStructureItemExporter(
		LayoutStructureItemExporter layoutStructureItemExporter) {

		_layoutStructureItemExporters.remove(layoutStructureItemExporter);
	}

	private final Map<String, LayoutStructureItemExporter>
		_layoutStructureItemExporters = new ConcurrentHashMap<>();

}