/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.layout.page.template.admin.web.internal.servlet.taglib.clay;

import com.liferay.frontend.taglib.clay.servlet.taglib.soy.VerticalCard;
import com.liferay.layout.page.template.model.LayoutPageTemplateEntry;
import com.liferay.portal.kernel.theme.ThemeDisplay;
import com.liferay.portal.kernel.util.HashMapBuilder;
import com.liferay.portal.kernel.util.ParamUtil;
import com.liferay.portal.kernel.util.PortalUtil;
import com.liferay.portal.kernel.util.WebKeys;

import java.util.Map;

import javax.portlet.ActionRequest;
import javax.portlet.PortletURL;
import javax.portlet.RenderRequest;
import javax.portlet.RenderResponse;

import javax.servlet.http.HttpServletRequest;

/**
 * @author Eudaldo Alonso
 */
public class SelectLayoutPageTemplateEntryMasterLayoutVerticalCard
	implements VerticalCard {

	public SelectLayoutPageTemplateEntryMasterLayoutVerticalCard(
		LayoutPageTemplateEntry layoutPageTemplateEntry,
		RenderRequest renderRequest, RenderResponse renderResponse) {

		_layoutPageTemplateEntry = layoutPageTemplateEntry;
		_renderResponse = renderResponse;

		_httpServletRequest = PortalUtil.getHttpServletRequest(renderRequest);
		_themeDisplay = (ThemeDisplay)renderRequest.getAttribute(
			WebKeys.THEME_DISPLAY);
	}

	@Override
	public Map<String, String> getData() {
		return HashMapBuilder.put(
			"add-layout-page-template-entry-url",
			() -> {
				long layoutPageTemplateCollectionId = ParamUtil.getLong(
					_httpServletRequest, "layoutPageTemplateCollectionId");

				PortletURL addLayoutPageTemplateEntryURL =
					_renderResponse.createActionURL();

				addLayoutPageTemplateEntryURL.setParameter(
					ActionRequest.ACTION_NAME,
					"/layout_page_template/add_layout_page_template_entry");
				addLayoutPageTemplateEntryURL.setParameter(
					"redirect", _themeDisplay.getURLCurrent());
				addLayoutPageTemplateEntryURL.setParameter(
					"layoutPageTemplateCollectionId",
					String.valueOf(layoutPageTemplateCollectionId));
				addLayoutPageTemplateEntryURL.setParameter(
					"masterLayoutPlid",
					String.valueOf(_layoutPageTemplateEntry.getPlid()));

				return addLayoutPageTemplateEntryURL.toString();
			}
		).build();
	}

	@Override
	public String getElementClasses() {
		return "add-master-page-action-option card-interactive " +
			"card-interactive-primary";
	}

	@Override
	public String getIcon() {
		return "page";
	}

	@Override
	public String getImageSrc() {
		return _layoutPageTemplateEntry.getImagePreviewURL(_themeDisplay);
	}

	@Override
	public String getTitle() {
		return _layoutPageTemplateEntry.getName();
	}

	@Override
	public boolean isSelectable() {
		return false;
	}

	private final HttpServletRequest _httpServletRequest;
	private final LayoutPageTemplateEntry _layoutPageTemplateEntry;
	private final RenderResponse _renderResponse;
	private final ThemeDisplay _themeDisplay;

}